@@ -14,7 +14,11 @@ __events__ = {
             "GroupMessage",
             "TempMessage",
             "StrangerMessage",
-            "OtherClientMessage"
+            "OtherClientMessage",
+            "GroupSyncMessage",
+            "FriendSyncMessage",
+            "TempSyncMessage",
+            "StrangerSyncMessage"
         ],
 }
 
@@ -465,44 +469,6 @@ class CommandExecutedEvent(EventBase):
     args: dict
 
 
-class FriendSyncMessage(EventBase):
-    """好友同步消息"""
-    type: str = "FriendSyncMessage"
-    subject: Friend
-    messageChain: MessageChain
-
-    def __str__(self) -> str:
-        return super().__str__()+": "+self.messageChain.__str__()
-
-
-class GroupSyncMessage(EventBase):
-    """群组同步消息"""
-    type: str = "GroupSyncMessage"
-    subject: Group
-    messageChain: MessageChain
-
-    def __str__(self) -> str:
-        return super().__str__()+": " + self.messageChain.__str__()
-
-
-class TempSyncMessage(EventBase):
-    """临时同步消息"""
-    type: str = "TempSyncMessage"
-    subject: Member
-    messageChain: MessageChain
-
-    def __str__(self) -> str:
-        return super().__str__()+": " + self.messageChain.__str__()
-
-
-class StrangerSyncMessage(EventBase):
-    """陌生人同步消息"""
-    type: str = "StrangerSyncMessage"
-    subject: Stranger
-    messageChain: MessageChain
-
-    def __str__(self) -> str:
-        return super().__str__()+": " + self.messageChain.__str__()
 
 
 class EventEnum(Enum):
@@ -547,11 +513,6 @@ class EventEnum(Enum):
     OtherClientOfflineEvent: "OtherClientOfflineEvent" = OtherClientOfflineEvent
     CommandExecutedEvent: "CommandExecutedEvent" = CommandExecutedEvent
 
-    FriendSyncMessage: "FriendSyncMessage" = FriendSyncMessage
-    GroupSyncMessage: "GroupSyncMessage" = GroupSyncMessage
-    TempSyncMessage: "TempSyncMessage" = TempSyncMessage
-    StrangerSyncMessage: "StrangerSyncMessage" = StrangerSyncMessage
-
 
 class Auto_Switch_Event(object):
     @staticmethod
